// Glass.cc -- generate output for a VRML 1.0 representation of a glass.
// @author Eric Laroche
// @version @(#)$Id: Glass.cc,v 1.9 1998/05/20 20:24:33 laroche Exp $
//
// Glass.cc -- generate output for a VRML 1.0 representation of a glass.
// Copyright (C) 1998 Eric Laroche.
//
// This program is free software;
// you can redistribute it and/or modify it.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.


static char const rcsid[] =
	"@(#)$Id: Glass.cc,v 1.9 1998/05/20 20:24:33 laroche Exp $";
static char const copyrid[] = "Copyright (C) 1998 Eric Laroche";


#include "VrmlGlass.h"
#include "GlassProfile.h"
#include "IsoGlassProfile.h"


#include <iostream.h>
#include <stdlib.h>
#include <string.h>


// application entry point
int main(int argc, char** argv)
{
	// application name
	char* app = argv[0];
	argv++, argc--;
	char* p = strrchr(app, '/');
	if ( p )
		app = &p[1];
	p = strrchr(app, '\\');
	if ( p )
		app = &p[1];

	if ( argc > 0 && !strcmp(argv[0], "-V") )
	{
		cout << rcsid << endl << copyrid << endl;
		return 0;
	}

	int resolution = 0;
	if ( argc > 1 && !strcmp(argv[0], "-r") )
	{
		resolution = atoi(argv[1]);
		argv += 2, argc -= 2;
	}

	if ( argc == 0 )
	{
		// generate the ISO 3591-1977 glass
		IsoGlassProfile igp;
		if ( resolution > 0 )
			vrmlglass(cout, &igp, resolution, resolution);
		else
			vrmlglass(cout, &igp);
	}
	else if ( argc == 7 )
	{
		// generate a custom ellipsoid-parabolic glass
		EpGlassProfile egp(atof(argv[0]), atof(argv[1]), atof(argv[2]),
			atof(argv[3]), atof(argv[4]), atof(argv[5]), atof(argv[6]));
		if ( resolution > 0 )
			vrmlglass(cout, &egp, resolution, resolution);
		else
			vrmlglass(cout, &egp);
	}
	else
	{
		// usage
		cerr << "Usage: " << app
			<< " [-r resolution]"
			<< " [footradius stemradius stemlength"
				" cupradius lowercuplength openingradius uppercuplength]"
			<< endl << flush;
		cerr << "e.g. a Bordeaux glass: " << app << " "
			<< "44 3.5 90.5 47 62.5 34.5 72"
			<< endl << flush;
		cerr << "or the ISO 3591-1977 glass (default): " << app << " "
			<< "32.5 4.5 55 32.5 32.5 23 67.5"
			<< endl << flush;
		cerr << endl << flush;
		cerr << app << " generates a VRML 1.0 (virtual reality modeling language,"
			" version 1.0) representation of a rotation-symmetric drinking glass."
			<< endl << flush;
		cerr << "The glass stem radius is defined by an exponential function,"
			" the lower part of the cup is an ellipsoid, the upper part a paraboloid."
			"  Samples are given above."
			<< endl << flush;
		return 1;
	}

	return 0;
}
